package net.knarcraft.paidsigns.command;

import net.knarcraft.paidsigns.PaidSigns;
import net.knarcraft.paidsigns.container.PaidSign;
import net.knarcraft.paidsigns.manager.PaidSignManager;
import net.knarcraft.paidsigns.property.OptionState;
import net.knarcraft.paidsigns.utility.Tokenizer;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * A representation of the command for adding a new paid sign
 */
public class AddCommand implements CommandExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label,
                             @NotNull String[] args) {
        if (args.length < 3) {
            return false;
        }
        PaidSignManager manager = PaidSigns.getInstance().getSignManager();
        List<String> arguments = Tokenizer.tokenize(String.join(" ", args));
        int argumentSize = args[args.length - 1].isEmpty() ? arguments.size() : arguments.size() - 1;

        String signName = arguments.get(0);
        double cost;
        try {
            cost = Double.parseDouble(arguments.get(2));
        } catch (NumberFormatException exception) {
            sender.sendMessage("You provided an invalid number");
            return false;
        }
        String permission = arguments.get(2);
        OptionState ignoreCase = OptionState.DEFAULT;
        OptionState ignoreColor = OptionState.DEFAULT;
        if (argumentSize > 3) {
            ignoreCase = OptionState.fromString(arguments.get(3));
        }
        if (argumentSize > 4) {
            ignoreColor = OptionState.fromString(arguments.get(4));
        }

        try {
            PaidSign sign = new PaidSign(signName, cost, permission, ignoreCase, ignoreColor);
            if (manager.getPaidSign(signName) != null) {
                sender.sendMessage("A paid sign with the same name already exists");
                return false;
            }
            manager.addPaidSign(sign);
            sender.sendMessage("Successfully added new paid sign");
            return true;
        } catch (IOException e) {
            Logger logger = PaidSigns.getInstance().getLogger();
            logger.log(Level.SEVERE, "Exception encountered while trying to write " +
                    "to the data file");
            logger.log(Level.SEVERE, Arrays.toString(e.getStackTrace()));
            sender.sendMessage("An exception occurred. Please notify the server administrator or check the server log.");
            return false;
        } catch (IllegalArgumentException e) {
            sender.sendMessage("Invalid input: " + e.getMessage());
        }
        return false;
    }

}
