package net.knarcraft.paidsigns.command;

import net.knarcraft.paidsigns.PaidSigns;
import net.knarcraft.paidsigns.container.PaidSign;
import net.knarcraft.paidsigns.property.OptionState;
import net.knarcraft.paidsigns.utility.Tokenizer;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

import java.util.List;

/**
 * A representation of the command for adding a new match condition for a sign
 */
public class AddConditionCommand implements CommandExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        List<String> arguments = Tokenizer.tokenize(String.join(" ", args));
        int argumentSize = args[args.length - 1].isEmpty() ? arguments.size() : arguments.size() - 1;
        if (argumentSize < 3) {
            return false;
        }

        String name = arguments.get(0);
        short lineNumber;
        try {
            lineNumber = (short) (Short.parseShort(arguments.get(1)) - 1);
        } catch (NumberFormatException exception) {
            sender.sendMessage("Invalid line number given");
            return false;
        }
        String stringToMatch = arguments.get(2);
        boolean executeRegEx = false;
        if (argumentSize > 3) {
            executeRegEx = Boolean.parseBoolean(arguments.get(3));
        }
        OptionState ignoreCase = OptionState.DEFAULT;
        if (argumentSize > 4) {
            ignoreCase = OptionState.getFromBoolean(Boolean.parseBoolean(arguments.get(4)));
        }
        OptionState ignoreColor = OptionState.DEFAULT;
        if (argumentSize > 5) {
            ignoreColor = OptionState.getFromBoolean(Boolean.parseBoolean(arguments.get(5)));
        }
        PaidSign sign = PaidSigns.getInstance().getSignManager().getPaidSign(name);
        if (sign == null) {
            sender.sendMessage("No such paid sign exists");
            return false;
        }
        sign.addCondition(lineNumber, stringToMatch, executeRegEx, ignoreCase, ignoreColor);
        sender.sendMessage("Condition added");
        return true;
    }

}
