package net.knarcraft.paidsigns.listener;

import net.knarcraft.paidsigns.PaidSigns;
import net.knarcraft.paidsigns.container.PaidSign;
import net.knarcraft.paidsigns.manager.EconomyManager;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.EventPriority;
import org.bukkit.event.Listener;
import org.bukkit.event.block.SignChangeEvent;

import java.util.Map;

/**
 * A listener for listening to registered paid signs
 */
public class SignListener implements Listener {

    @EventHandler(priority = EventPriority.LOW)
    @SuppressWarnings("unused")
    public void onSignChange(SignChangeEvent event) {
        if (event.isCancelled() || event.getPlayer().hasPermission("paidsigns.paymentexempt")) {
            return;
        }

        String[] lines = event.getLines();
        Map<String, PaidSign> matchingSigns = PaidSigns.getInstance().getSignManager().getAllPaidSigns();
        for (PaidSign paidSign : matchingSigns.values()) {
            //If a match is found, just return
            if (matchSign(paidSign, lines, event)) {
                return;
            }
        }
    }

    /**
     * Checks if the given paid sign matches the given sign lines
     *
     * @param paidSign <p>The paid sign to test against the sign lines</p>
     * @param lines    <p>The lines of a sign</p>
     * @param event    <p>The triggered sign change event to cancel if necessary</p>
     * @return <p>True if a match was found and actions have been taken</p>
     */
    private boolean matchSign(PaidSign paidSign, String[] lines, SignChangeEvent event) {
        if (paidSign.matches(lines)) {
            Player player = event.getPlayer();
            String permission = paidSign.getPermission();
            //If a match is found, but the player is missing the permission, assume no plugin sign was created
            if (permission != null && !permission.trim().isEmpty() && !player.hasPermission(permission)) {
                return true;
            }

            double cost = paidSign.getCost();
            boolean canAfford = EconomyManager.canAfford(player, cost);
            if (!canAfford) {
                player.sendMessage("[PaidSigns] You cannot afford to create this sign");
                event.setCancelled(true);
            } else {
                String unit = EconomyManager.getCurrency(cost != 1);
                player.sendMessage(String.format("[PaidSigns] You paid %.2f %s to create the sign", cost, unit));
                EconomyManager.withdraw(player, cost);
            }
            return true;
        }
        return false;
    }

}
